
include("FLuaVector.lua");
local pCiv = GameInfoTypes.CIVILIZATION_THP_FATIMID_MUIZZ

---------------------------------
-- GS points from Faith purchases
---------------------------------

local sScientist = GameInfo.Specialists.SPECIALIST_SCIENTIST.ID

function PointsFromUnits(playerID, cityID, unitID, bGold, bFaith)
	local pPlayer = Players[playerID]
	if pPlayer:GetCivilizationType() ~= pCiv then return end
	if bFaith then
		local pCity = pPlayer:GetCityByID(cityID)
		local pUnit = pPlayer:GetUnitByID(unitID)
		if pUnit:IsGreatPerson() then
			-- to buy GP w/ Faith, you need to already be in the Industrial Era...
			-- ...so with any luck this will be balanced
			pCity:ChangeSpecialistGreatPersonProgressTimes100(sScientist, 5000)
		else
			pCity:ChangeSpecialistGreatPersonProgressTimes100(sScientist, 1500)
		end
	end
end

GameEvents.CityTrained.Add(PointsFromUnits)

function PointsFromBuildings(playerID, cityID, buildingType, bGold, bFaith)
	local pPlayer = Players[playerID]
	if pPlayer:GetCivilizationType() ~= pCiv then return end
	if bFaith then
		local pCity = pPlayer:GetCityByID(cityID)
		pCity:ChangeSpecialistGreatPersonProgressTimes100(sScientist, 2500)
	end
end

GameEvents.CityConstructed.Add(PointsFromBuildings)

----------------------------------------
-- Science from Missionaries/Inquisitors
----------------------------------------

local uMissionary = GameInfoTypes.UNIT_MISSIONARY
local uInquisitor = GameInfoTypes.UNIT_INQUISITOR

local gsQuick = GameInfoTypes.GAMESPEED_QUICK
local gsEpic = GameInfoTypes.GAMESPEED_EPIC
local gsMarathon = GameInfoTypes.GAMESPEED_MARATHON

-- This function is heavily derived from the Seminary Lua for JFD's Spain

function ScienceBurstQuantity(player)
    local scienceBurst = (player:GetScience())
    if Game.GetGameSpeedType() == gsQuick then
        scienceBurst = (2 * scienceBurst) / 3
    elseif Game.GetGameSpeedType() == gsEpic then
        scienceBurst = 1.5 * scienceBurst
    elseif Game.GetGameSpeedType() == gsMarathon then
        scienceBurst = 3 * scienceBurst
    end
    return scienceBurst
end

function MissionScience(playerID, unitID, unitType, plotX, plotY, isDelay, otherPlayerID)
	local player = Players[playerID]
	if (isDelay) then return end
	if (not player:IsAlive()) then return end
	if (not player:GetCivilizationType() == pCiv) then return end
	if (otherPlayerID ~= -1) then return end
	local scienceBurst = 0
	local unit = player:GetUnitByID(unitID)
	if (unit:GetUnitType() == uMissionary) or (unit:GetUnitType() == uInquisitor) then
        	scienceBurst = ScienceBurstQuantity(player)
		if player:IsHuman() then
			Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(plotX, plotY))), "[COLOR_RESEARCH_STORED]+" .. scienceBurst .. " [ICON_RESEARCH] Science[ENDCOLOR]", 0)
		end
		local pTeam = Teams[player:GetTeam()]
		local tCurrentTech = player:GetCurrentResearch()
		pTeam:GetTeamTechs():ChangeResearchProgress(tCurrentTech, scienceBurst, player)
	end
end

GameEvents.UnitPrekill.Add(MissionScience)

--------------------------
-- Additional Achievements
--------------------------

include("AdditionalAchievementsUtility.lua");

function JFDGame_IsAAActive()
	for _, mod in pairs(Modding.GetActivatedMods()) do
		if mod.ID == "432bc547-eb05-4189-9e46-232dbde8f09f" then
			return true
		end
	end
	return false
end
local isAAActive = JFDGame_IsAAActive()

local pSciPolicy1 = GameInfoTypes.POLICY_AA_THP_MUIZZ_SCI_DUMMY_1
local pSciPolicy2 = GameInfoTypes.POLICY_AA_THP_MUIZZ_SCI_DUMMY_2
local uScientist = GameInfoTypes.UNIT_SCIENTIST

function MuizzAACheck(playerID, cityID, uUnitType, bGold, bFaith)
	if IsAAUnlocked('AA_THP_MUIZZ_SPECIAL') then return end
	local pPlayer = Players[playerID]
	if not pPlayer:IsHuman() then return end
	if pPlayer:GetCivilizationType() == pCiv then
		if bFaith and (uUnitType == uScientist) then
			if pPlayer:HasPolicy(pSciPolicy1) then
				if pPlayer:HasPolicy(pSciPolicy2) then
					UnlockAA('AA_THP_MUIZZ_SPECIAL');
				else
					pPlayer:SetNumFreePolicies(1)
					pPlayer:SetNumFreePolicies(0)
					pPlayer:SetHasPolicy(pSciPolicy2, true)
				end
			else
				pPlayer:SetNumFreePolicies(1)
				pPlayer:SetNumFreePolicies(0)
				pPlayer:SetHasPolicy(pSciPolicy1, true)
			end
		end
	end
end

if isAAActive then
	GameEvents.CityTrained.Add(MuizzAACheck)
end

