
local pCiv = GameInfoTypes.CIVILIZATION_THP_FATIMID_MUIZZ
local cClass = GameInfoTypes.UNITCLASS_CROSSBOWMAN
local uAhdath = GameInfoTypes.UNIT_THP_AHDATH
local pIsAtWar = GameInfoTypes.POLICY_THP_AHDATH_AT_WAR

------------
-- this section of stuff checks whether another civ has the same religion as you
------------

function DoYouShareReligions(pFatimidPlayer, pOtherPlayer)
	local pYourReligion = nil
	local pOtherReligion = nil
	if pFatimidPlayer:HasCreatedReligion() then
		pYourReligion = pFatimidPlayer:GetReligionCreatedByPlayer()
	else
        if pFatimidPlayer:GetCapitalCity() == nil then
            pYourReligion = -1
        else
            pYourReligion = pFatimidPlayer:GetCapitalCity():GetReligiousMajority()
        end
	end
	if pOtherPlayer:HasCreatedReligion() then
		pOtherReligion = pOtherPlayer:GetReligionCreatedByPlayer()
	else
        if pOtherPlayer:GetCapitalCity() == nil then
            pOtherReligion = -1
        else
		    pOtherReligion = pOtherPlayer:GetCapitalCity():GetReligiousMajority()
        end
	end
	if pYourReligion == pOtherReligion then
		return true
	else
		return false
	end
end

------------
-- this function checks if you're at war with a religious rival
------------

function IsAtWarWithReligiousRival(player)
	local tYourTeam = Teams[player:GetTeam()]
	local isWar = false
	for otherTeamID, otherTeam in pairs(Teams) do
		if tYourTeam:IsAtWar(otherTeamID) then
			if not otherTeam:IsBarbarian() then
				local pOther = Players[otherTeam:GetLeaderID()]
				if DoYouShareReligions(player, pOther) == false then
					isWar = true
					return isWar
				end
			end
		end
	end
	return isWar
end

------------
-- this section links the religions to war/peace, and gives the Ahdath appropriate defensive promotions
------------

-- this boosts the strength of the ahdath when at war with a civ of a different religion. the policy prevents it from stacking

function AhdathPromote(declarerID, declaredUponID)
	local tDeclarer = Teams[declarerID]
	local pDeclarer = Players[tDeclarer:GetLeaderID()]
	local tDeclaredUpon = Teams[declaredUponID]
	local pDeclaredUpon = Players[tDeclaredUpon:GetLeaderID()]
	if pDeclarer:GetCivilizationType() == pCiv then
		if pDeclarer:HasUnitOfClassType(cClass) then
			if not pDeclarer:HasPolicy(pIsAtWar) then
				if not DoYouShareReligions(pDeclarer, pDeclaredUpon) then
					pDeclarer:SetNumFreePolicies(1)
					pDeclarer:SetNumFreePolicies(0)
					pDeclarer:SetHasPolicy(pIsAtWar, true)
					for pUnit in pDeclarer:Units() do
						if pUnit:GetUnitType() == uAhdath then
							local iStrength = pUnit:GetBaseCombatStrength()
							pUnit:SetBaseCombatStrength(iStrength + 3)
						end
					end
				end
			end
		end
	end
	-- this isn't an elseif, in case there are two Fatimids in the game and they go to war with each other
	if pDeclaredUpon:GetCivilizationType() == pCiv then
		if pDeclaredUpon:HasUnitOfClassType(cClass) then
			if not pDeclaredUpon:HasPolicy(pIsAtWar) then
				if not DoYouShareReligions(pDeclaredUpon, pDeclarer) then
					pDeclaredUpon:SetNumFreePolicies(1)
					pDeclaredUpon:SetNumFreePolicies(0)
					pDeclaredUpon:SetHasPolicy(pIsAtWar, true)
					for pUnit in pDeclaredUpon:Units() do
						if pUnit:GetUnitType() == uAhdath then
							local iStrength = pUnit:GetBaseCombatStrength()
							pUnit:SetBaseCombatStrength(iStrength + 3)
						end
					end
				end
			end
		end
	end
end

GameEvents.DeclareWar.Add(AhdathPromote)

-- this reduces the strength of the ahdath once the Fatimids are no longer at war w/ other religions

function AhdathDemote(peacerID, peacedUponID)
	local tPeacer = Teams[peacerID]
	local pPeacer = Players[tPeacer:GetLeaderID()]
	local tPeacedUpon = Teams[peacedUponID]
	local pPeacedUpon = Players[tPeacedUpon:GetLeaderID()]
	if pPeacer:GetCivilizationType() == pCiv then
		local endOfReligiousWar = true
		if IsAtWarWithReligiousRival(pPeacer) then
			endOfReligiousWar = false
		end
		if endOfReligiousWar then
			pPeacer:SetHasPolicy(pIsAtWar, false)
			if pPeacer:HasUnitOfClassType(cClass) then
				for pUnit in pPeacer:Units() do
					if pUnit:GetUnitType() == uAhdath then
						local iStrength = pUnit:GetBaseCombatStrength()
						pUnit:SetBaseCombatStrength(iStrength - 3)
					end
				end	
			end
		end
	end
	if pPeacedUpon:GetCivilizationType() == pCiv then
		local endOfReligiousWar = true
		if IsAtWarWithReligiousRival(pPeacedUpon) then
			endOfReligiousWar = false
		end
		if endOfReligiousWar then
			pPeacedUpon:SetHasPolicy(pIsAtWar, false)
			if pPeacedUpon:HasUnitOfClassType(cClass) then
				for pUnit in pPeacedUpon:Units() do
					if pUnit:GetUnitType() == uAhdath then
						local iStrength = pUnit:GetBaseCombatStrength()
						pUnit:SetBaseCombatStrength(iStrength - 3)
					end
				end	
			end
		end
	end
end

GameEvents.MakePeace.Add(AhdathDemote)

------------
-- this function updates the combat strength of an ahdath trained *during* an ongoing religious war
------------

function PrepNewAhdath(playerID, cityID, unitID)
	local pPlayer = Players[playerID]
	local uNewUnit = pPlayer:GetUnitByID(unitID)
	if pPlayer:GetCivilizationType() == pCiv then
		if uNewUnit:GetUnitType() == uAhdath then
			if IsAtWarWithReligiousRival(pPlayer) then
				local iStrength = uNewUnit:GetBaseCombatStrength()
				uNewUnit:SetBaseCombatStrength(iStrength + 3)
			end
		end
	end
end

GameEvents.CityTrained.Add(PrepNewAhdath)
